@@ -3,11 +3,13 @@ import sys
 if sys.version_info[0] >= 3:
     from urllib.request import urlopen
     from urllib.parse import quote_plus
+    from urllib.parse import urlencode
     from urllib.error import HTTPError
 else:
     from urllib2 import urlopen
     from urllib2 import HTTPError
     from urllib import quote_plus
+    from urllib import urlencode
 
 import xml.etree.ElementTree as ET
 from dateutil.parser import parse
@@ -19,7 +21,6 @@ class Fred(object):
     latest_realtime_end = '9999-12-31'
     nan_char = '.'
     max_results_per_request = 1000
-
     def __init__(self,
                  api_key=None,
                  api_key_file=None):
@@ -52,8 +53,9 @@ class Fred(object):
         try:
             response = urlopen(url)
             root = ET.fromstring(response.read())
-        except HTTPError:
-            root = None
+        except HTTPError, exc:
+            root = ET.fromstring(exc.read())
+            raise ValueError(root.get('message'))
         return root
 
     def get_series_info(self, series_id):
@@ -77,7 +79,7 @@ class Fred(object):
         info = pd.Series(root.getchildren()[0].attrib)
         return info
 
-    def get_series(self, series_id):
+    def get_series(self, series_id, observation_start=None, observation_end=None, **kwargs):
         """
         Get data for a Fred series id. This fetches the latest known data, and is equivalent to get_series_latest_release()
 
@@ -85,13 +87,30 @@ class Fred(object):
         ----------
         series_id : str
             Fred series id such as 'CPIAUCSL'
+        observation_start : datetime or datetime-like str such as '7/1/2014', optional
+            earliest observation date
+        observation_end : datetime or datetime-like str such as '7/1/2014', optional
+            latest observation date
+        kwargs : additional parameters
+            Any additional parameters supported by FRED. You can see http://api.stlouisfed.org/docs/fred/series_observations.html for the full list
 
         Returns
         -------
-        info : Series
+        data : Series
             a Series where each index is the observation date and the value is the data for the Fred series
         """
         url = "http://api.stlouisfed.org/fred/series/observations?series_id=%s&api_key=%s" % (series_id, self.api_key)
+
+        if observation_start is not None:
+            observation_start = pd.to_datetime(observation_start, errors='raise')
+            url += '&observation_start=' + observation_start.strftime('%Y-%m-%d')
+        if observation_end is not None:
+            observation_end = pd.to_datetime(observation_end, errors='raise')
+            url += '&observation_end=' + observation_end.strftime('%Y-%m-%d')
+
+        if kwargs is not None:
+            url += '&' + urlencode(kwargs)
+
         root = self.__fetch_data(url)
         if root is None:
             raise ValueError('No data exists for series id: ' + series_id)
